@@ -152,8 +152,7 @@ def hex_to_binary(hex_string):
 
 
 # TODO: Consider support road closures
-DEFAULT_EVENT_TYPE = ('work-zone', [{'type_name': 'roadside-work',
-                      'is_architectural_change': False}])
+DEFAULT_EVENT_TYPE = ('work-zone', [])
 EVENT_TYPE_MAPPING = {
     "Bridge Construction":              ('work-zone', [{'type_name': 'below-road-work',            'is_architectural_change': True}]),
     "Road Construction":                ('work-zone', [{'type_name': 'roadway-creation',           'is_architectural_change': True}]),
@@ -182,11 +181,11 @@ EVENT_TYPE_MAPPING = {
     "Utility Work":                     ('work-zone', [{'type_name': 'roadside-work',              'is_architectural_change': False}]),
     "Utility Installation":             ('work-zone', [{'type_name': 'roadside-work',              'is_architectural_change': False}]),
     "Wall Maintenance":                 ('work-zone', [{'type_name': 'barrier-work',               'is_architectural_change': False}]),
+    "Other":                            ('work-zone', []),
 
     "BAN Message":                      ('restriction', []),
     "Safety Campaign":                  ('restriction', []),
     "Smoke/Control Burn":               ('restriction', []),
-    "Other":                            ('restriction', []),
     "Avalanche Control":                ('restriction', []),
     "Closed for the Season":            ('restriction', []),
     "Funeral Procession":               ('restriction', []),
@@ -203,7 +202,7 @@ LANE_TYPE_MAPPING = {
     "left lane": 'general',
     "center lane": 'general',
     "middle two lanes": 'general',
-    'general': 'general',
+    "general": 'general',
     # this is a weird one
     "middle lanes": 'general',
     "right lane": 'general',
@@ -334,7 +333,6 @@ def create_rtdh_standard_msg(pd):
             "types_of_work": types_of_work,
             "source": {
                 "id": pd.get("properties/id", default="") + '_' + direction,
-                "creation_timestamp": pd.get("properties/startTime", date_tools.get_unix_from_iso_string, default=0),
                 "last_updated_timestamp": pd.get('properties/lastUpdated', date_tools.get_unix_from_iso_string, default=0),
             },
             "geometry": coordinates,
@@ -353,6 +351,7 @@ def create_rtdh_standard_msg(pd):
                 "restrictions": restrictions,
                 "beginning_milepost": beginning_milepost,
                 "ending_milepost": ending_milepost,
+                "valid": False,
             }
         }
     }
